import React from 'react';
import { Star, MapPin, Phone, Globe, Clock, ExternalLink } from 'lucide-react';
import { Card, CardHeader, CardTitle, CardContent, CardFooter } from './UI/Card';
import { Badge } from './UI/Badge';
import { Button } from './UI/Button';
import { Place } from '../types';
import { formatDistance, formatRating, formatPriceLevel, getCategoryIconName } from '../lib/utils';

interface PlaceCardProps {
  place: Place;
  index: number;
  onViewDetails: (place: Place) => void;
}

export function PlaceCard({ place, index, onViewDetails }: PlaceCardProps) {
  const CategoryIcon = getCategoryIconName(place.category);
  
  return (
    <Card 
      className="w-full h-full flex flex-col bg-card dark:bg-gray-800 hover:shadow-lg transition-shadow duration-200" 
      index={index}
    >
      {place.photos && place.photos.length > 0 && (
        <div className="relative h-48 overflow-hidden">
          <img 
            src={place.photos[0]} 
            alt={place.name} 
            className="w-full h-full object-cover"
          />
          <div className="absolute top-2 right-2">
            <Badge 
              variant="info" 
              className="flex items-center gap-1 font-medium"
            >
              <MapPin size={12} />
              {formatDistance(place.distance)}
            </Badge>
          </div>
        </div>
      )}
      
      <CardHeader className="pb-2">
        <div className="flex items-start justify-between">
          <div>
            <Badge 
              variant="secondary" 
              className="mb-2 capitalize"
            >
              {place.category}
            </Badge>
            <CardTitle className="text-xl">{place.name}</CardTitle>
          </div>
          {place.priceLevel && (
            <Badge variant="outline">
              {formatPriceLevel(place.priceLevel)}
            </Badge>
          )}
        </div>
      </CardHeader>
      
      <CardContent className="flex-grow">
        <p className="text-sm text-muted-foreground mb-4 line-clamp-2">
          {place.description}
        </p>
        
        <div className="space-y-2 text-sm">
          <div className="flex items-center gap-2 text-amber-500">
            <Star size={16} className="fill-amber-500" />
            <span className="font-medium">{formatRating(place.rating)}</span>
          </div>
          
          <div className="flex items-start gap-2">
            <MapPin size={16} className="mt-0.5 text-gray-500" />
            <span className="text-muted-foreground">{place.address}</span>
          </div>
          
          {place.openHours && (
            <div className="flex items-start gap-2">
              <Clock size={16} className="mt-0.5 text-gray-500" />
              <span className="text-muted-foreground">{place.openHours}</span>
            </div>
          )}
        </div>
      </CardContent>
      
      <CardFooter className="flex justify-between">
        <Button 
          variant="outline" 
          size="sm"
          className="text-xs"
          onClick={() => onViewDetails(place)}
        >
          View Details
        </Button>
        
        <div className="flex gap-1">
          {place.phoneNumber && (
            <Button
              variant="ghost"
              size="icon"
              className="h-8 w-8"
              asChild
            >
              <a href={`tel:${place.phoneNumber}`} aria-label="Call">
                <Phone size={16} />
              </a>
            </Button>
          )}
          
          {place.website && (
            <Button
              variant="ghost"
              size="icon"
              className="h-8 w-8"
              asChild
            >
              <a 
                href={place.website} 
                target="_blank" 
                rel="noopener noreferrer"
                aria-label="Visit website"
              >
                <ExternalLink size={16} />
              </a>
            </Button>
          )}
        </div>
      </CardFooter>
    </Card>
  );
}