import React from 'react';
import { motion } from 'framer-motion';
import { X, Star, MapPin, Phone, Globe, Clock, ExternalLink } from 'lucide-react';
import { Button } from './UI/Button';
import { Badge } from './UI/Badge';
import { Place } from '../types';
import { formatRating, formatPriceLevel } from '../lib/utils';

interface PlaceDetailProps {
  place: Place;
  onClose: () => void;
}

export function PlaceDetail({ place, onClose }: PlaceDetailProps) {
  return (
    <motion.div
      initial={{ opacity: 0, scale: 0.95 }}
      animate={{ opacity: 1, scale: 1 }}
      exit={{ opacity: 0, scale: 0.95 }}
      transition={{ duration: 0.2 }}
      className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50 flex items-center justify-center p-4"
      onClick={onClose}
    >
      <motion.div
        initial={{ y: 20 }}
        animate={{ y: 0 }}
        className="bg-card dark:bg-gray-800 rounded-lg shadow-xl w-full max-w-2xl max-h-[90vh] overflow-auto"
        onClick={(e) => e.stopPropagation()}
      >
        <div className="relative">
          {/* Header image */}
          {place.photos && place.photos.length > 0 ? (
            <div className="relative h-64">
              <img 
                src={place.photos[0]} 
                alt={place.name} 
                className="w-full h-full object-cover"
              />
              <div className="absolute inset-0 bg-gradient-to-t from-black/70 to-transparent"></div>
              
              {/* Close button */}
              <Button
                variant="ghost"
                size="icon"
                className="absolute top-4 right-4 text-white bg-black/20 hover:bg-black/40"
                onClick={onClose}
              >
                <X size={20} />
              </Button>
              
              {/* Title and badges overlay */}
              <div className="absolute bottom-0 left-0 right-0 p-6 text-white">
                <div className="flex flex-wrap gap-2 mb-2">
                  <Badge variant="secondary" className="capitalize">
                    {place.category}
                  </Badge>
                  {place.priceLevel && (
                    <Badge variant="outline" className="text-white border-white/50">
                      {formatPriceLevel(place.priceLevel)}
                    </Badge>
                  )}
                </div>
                <h1 className="text-2xl font-bold">{place.name}</h1>
              </div>
            </div>
          ) : (
            <div className="flex justify-between items-center p-6">
              <div>
                <div className="flex flex-wrap gap-2 mb-2">
                  <Badge variant="secondary" className="capitalize">
                    {place.category}
                  </Badge>
                  {place.priceLevel && (
                    <Badge variant="outline">
                      {formatPriceLevel(place.priceLevel)}
                    </Badge>
                  )}
                </div>
                <h1 className="text-2xl font-bold">{place.name}</h1>
              </div>
              <Button
                variant="ghost"
                size="icon"
                onClick={onClose}
              >
                <X size={20} />
              </Button>
            </div>
          )}
        </div>
        
        {/* Content */}
        <div className="p-6">
          <div className="flex items-center gap-2 mb-4">
            <div className="flex items-center gap-1 text-amber-500">
              <Star size={18} className="fill-amber-500" />
              <span className="font-medium">{formatRating(place.rating)}</span>
            </div>
          </div>
          
          <div className="mb-6">
            <h2 className="text-lg font-semibold mb-2">About</h2>
            <p className="text-muted-foreground">
              {place.description}
            </p>
          </div>
          
          <div className="space-y-4 mb-6">
            <h2 className="text-lg font-semibold">Details</h2>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
              <div className="flex items-start gap-2">
                <MapPin size={18} className="mt-0.5 text-gray-500" />
                <span className="text-muted-foreground">{place.address}</span>
              </div>
              
              {place.openHours && (
                <div className="flex items-start gap-2">
                  <Clock size={18} className="mt-0.5 text-gray-500" />
                  <span className="text-muted-foreground">{place.openHours}</span>
                </div>
              )}
              
              {place.phoneNumber && (
                <div className="flex items-start gap-2">
                  <Phone size={18} className="mt-0.5 text-gray-500" />
                  <a 
                    href={`tel:${place.phoneNumber}`} 
                    className="text-muted-foreground hover:text-primary transition-colors"
                  >
                    {place.phoneNumber}
                  </a>
                </div>
              )}
              
              {place.website && (
                <div className="flex items-start gap-2">
                  <Globe size={18} className="mt-0.5 text-gray-500" />
                  <a 
                    href={place.website} 
                    target="_blank" 
                    rel="noopener noreferrer"
                    className="text-muted-foreground hover:text-primary transition-colors"
                  >
                    Website
                    <ExternalLink size={14} className="inline ml-1" />
                  </a>
                </div>
              )}
            </div>
          </div>
          
          {/* Gallery */}
          {place.photos && place.photos.length > 1 && (
            <div className="mb-6">
              <h2 className="text-lg font-semibold mb-2">Photos</h2>
              <div className="grid grid-cols-3 gap-2">
                {place.photos.slice(1).map((photo, index) => (
                  <div key={index} className="aspect-square overflow-hidden rounded-md">
                    <img 
                      src={photo} 
                      alt={`${place.name} photo ${index + 2}`} 
                      className="w-full h-full object-cover hover:scale-105 transition-transform duration-300"
                    />
                  </div>
                ))}
              </div>
            </div>
          )}
          
          <div className="flex justify-end gap-2">
            {place.website && (
              <Button
                variant="outline"
                className="flex items-center gap-1"
                asChild
              >
                <a 
                  href={place.website} 
                  target="_blank" 
                  rel="noopener noreferrer"
                >
                  Visit Website
                  <ExternalLink size={14} />
                </a>
              </Button>
            )}
            
            <Button
              variant="default"
              className="flex items-center gap-1"
              asChild
            >
              <a 
                href={`https://www.google.com/maps/search/?api=1&query=${encodeURIComponent(
                  `${place.name} ${place.address}`
                )}`} 
                target="_blank" 
                rel="noopener noreferrer"
              >
                View on Google Maps
                <MapPin size={14} />
              </a>
            </Button>
          </div>
        </div>
      </motion.div>
    </motion.div>
  );
}