import React from 'react';
import { motion } from 'framer-motion';
import { Utensils, Coffee, GlassWater, Building2, ShoppingBag, Landmark, Trees as Tree, Dumbbell, MapPin, SlidersHorizontal } from 'lucide-react';
import { Button } from './UI/Button';
import { Badge } from './UI/Badge';
import { PlaceCategory } from '../types';

interface CategoryOption {
  value: PlaceCategory;
  label: string;
  icon: React.ReactNode;
}

const categories: CategoryOption[] = [
  { value: 'restaurant', label: 'Restaurants', icon: <Utensils size={16} /> },
  { value: 'cafe', label: 'Cafes', icon: <Coffee size={16} /> },
  { value: 'bar', label: 'Bars', icon: <GlassWater size={16} /> },
  { value: 'hotel', label: 'Hotels', icon: <Building2 size={16} /> },
  { value: 'store', label: 'Stores', icon: <ShoppingBag size={16} /> },
  { value: 'attraction', label: 'Attractions', icon: <Landmark size={16} /> },
  { value: 'park', label: 'Parks', icon: <Tree size={16} /> },
  { value: 'gym', label: 'Gyms', icon: <Dumbbell size={16} /> },
  { value: 'other', label: 'Other', icon: <MapPin size={16} /> },
];

interface PlaceFiltersProps {
  selectedCategories: PlaceCategory[];
  onCategoryChange: (categories: PlaceCategory[]) => void;
  searchRadius: number;
  onRadiusChange: (radius: number) => void;
}

export function PlaceFilters({
  selectedCategories,
  onCategoryChange,
  searchRadius,
  onRadiusChange,
}: PlaceFiltersProps) {
  const toggleCategory = (category: PlaceCategory) => {
    if (selectedCategories.includes(category)) {
      onCategoryChange(selectedCategories.filter(c => c !== category));
    } else {
      onCategoryChange([...selectedCategories, category]);
    }
  };

  const clearCategories = () => {
    onCategoryChange([]);
  };

  const handleRadiusChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    onRadiusChange(parseInt(event.target.value, 10));
  };

  return (
    <motion.div
      initial={{ opacity: 0, y: -10 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.3 }}
      className="bg-white dark:bg-gray-800 rounded-lg shadow-md p-4 mb-4"
    >
      <div className="flex flex-col gap-4">
        <div className="flex items-center justify-between">
          <h2 className="text-lg font-semibold flex items-center gap-2">
            <SlidersHorizontal size={18} className="text-primary" />
            Filters
          </h2>
          {selectedCategories.length > 0 && (
            <Button
              variant="ghost"
              size="sm"
              onClick={clearCategories}
              className="text-xs text-muted-foreground"
            >
              Clear All
            </Button>
          )}
        </div>
        
        <div>
          <label className="block text-sm font-medium mb-2">
            Search Radius: {searchRadius / 1000} km
          </label>
          <input
            type="range"
            min="500"
            max="5000"
            step="500"
            value={searchRadius}
            onChange={handleRadiusChange}
            className="w-full h-2 bg-gray-200 dark:bg-gray-700 rounded-lg appearance-none cursor-pointer accent-primary"
          />
          <div className="flex justify-between text-xs text-muted-foreground mt-1">
            <span>0.5 km</span>
            <span>5 km</span>
          </div>
        </div>
        
        <div>
          <label className="block text-sm font-medium mb-2">Categories</label>
          <div className="flex flex-wrap gap-2">
            {categories.map((category) => (
              <Badge
                key={category.value}
                variant={selectedCategories.includes(category.value) ? 'default' : 'outline'}
                className="cursor-pointer flex items-center gap-1 py-1 px-2"
                onClick={() => toggleCategory(category.value)}
              >
                {category.icon}
                {category.label}
              </Badge>
            ))}
          </div>
        </div>
      </div>
    </motion.div>
  );
}