import React, { useState, useCallback } from 'react';
import Map, { Marker, NavigationControl, Popup } from 'react-map-gl';
import 'mapbox-gl/dist/mapbox-gl.css';
import { LocationData, Place } from '../types';
import { formatRating } from '../lib/utils';

// Mapbox public token - this is safe to expose in client-side code
const MAPBOX_TOKEN = 'pk.eyJ1IjoiZXhhbXBsZS11c2VyIiwiYSI6ImNrd2VzZ3l2NDJnMXMyb28xYm9yamVsZWsifQ.UZIGHXxFoS6eR_zNGCG5yw';

interface PlaceMapProps {
  userLocation: LocationData | null;
  places: Place[];
  onMarkerClick: (place: Place) => void;
  selectedPlace: Place | null;
}

export function PlaceMap({ 
  userLocation,
  places,
  onMarkerClick,
  selectedPlace
}: PlaceMapProps) {
  const [viewport, setViewport] = useState({
    latitude: userLocation?.latitude || 40.7128,
    longitude: userLocation?.longitude || -74.0060,
    zoom: 13
  });

  const handleMarkerClick = useCallback((place: Place) => {
    onMarkerClick(place);
  }, [onMarkerClick]);

  return (
    <div className="h-full w-full rounded-lg overflow-hidden shadow-lg">
      <Map
        {...viewport}
        mapboxAccessToken={MAPBOX_TOKEN}
        mapStyle="mapbox://styles/mapbox/streets-v12"
        onMove={evt => setViewport(evt.viewState)}
      >
        {/* User location marker */}
        {userLocation && (
          <Marker
            longitude={userLocation.longitude}
            latitude={userLocation.latitude}
            anchor="center"
          >
            <div className="relative">
              <div className="absolute -translate-x-1/2 -translate-y-1/2 h-6 w-6 bg-blue-500 rounded-full border-2 border-white shadow-md flex items-center justify-center">
                <div className="h-2 w-2 bg-white rounded-full"></div>
              </div>
              <div className="absolute -translate-x-1/2 -translate-y-1/2 h-12 w-12 bg-blue-500/30 rounded-full animate-ping-slow"></div>
            </div>
          </Marker>
        )}

        {/* Place markers */}
        {places.map(place => (
          <Marker
            key={place.id}
            longitude={place.coordinates.longitude}
            latitude={place.coordinates.latitude}
            anchor="bottom"
            onClick={() => handleMarkerClick(place)}
          >
            <div className={`h-8 w-8 flex items-center justify-center rounded-full cursor-pointer transform transition-all duration-200 ${
              selectedPlace?.id === place.id 
                ? 'bg-primary text-white scale-125' 
                : 'bg-white text-gray-700 hover:scale-110'
            } shadow-md border border-gray-300`}>
              <span className="text-xs font-bold">{place.rating.toFixed(1)}</span>
            </div>
          </Marker>
        ))}

        {/* Selected place popup */}
        {selectedPlace && (
          <Popup
            anchor="bottom"
            longitude={selectedPlace.coordinates.longitude}
            latitude={selectedPlace.coordinates.latitude}
            onClose={() => onMarkerClick(null as unknown as Place)}
            closeButton={true}
            closeOnClick={false}
            className="z-10"
          >
            <div className="p-2 max-w-xs">
              <h3 className="font-semibold text-sm">{selectedPlace.name}</h3>
              <div className="text-xs flex items-center gap-1 text-amber-500 mt-1">
                <span className="font-medium">{formatRating(selectedPlace.rating)}</span>
              </div>
              <p className="text-xs text-gray-600 mt-1 line-clamp-2">
                {selectedPlace.address}
              </p>
            </div>
          </Popup>
        )}

        <NavigationControl position="bottom-right" />
      </Map>
    </div>
  );
}