import React, { useState } from 'react';
import { AnimatePresence } from 'framer-motion';
import { useLocation } from '../hooks/useLocation';
import { usePlaces } from '../hooks/usePlaces';
import { Place } from '../types';
import { exportToExcel } from '../lib/utils';
import { ArrowLeft, Download } from 'lucide-react';

import { PlaceFilters } from './PlaceFilters';
import { PlaceCard } from './PlaceCard';
import { PlaceMap } from './PlaceMap';
import { PlaceDetail } from './PlaceDetail';
import { EmptyState } from './EmptyState';
import { Spinner } from './UI/Spinner';
import { Button } from './UI/Button';

interface PlacesExplorerProps {
  onBack: () => void;
}

export function PlacesExplorer({ onBack }: PlacesExplorerProps) {
  const { 
    location, 
    error: locationError, 
    loading: locationLoading, 
    refreshLocation 
  } = useLocation();
  
  const {
    places,
    loading: placesLoading,
    error: placesError,
    fetchPlaces,
    selectedCategories,
    setSelectedCategories,
    searchRadius,
    setSearchRadius,
  } = usePlaces();
  
  const [selectedPlace, setSelectedPlace] = useState<Place | null>(null);
  const [showMap, setShowMap] = useState<boolean>(false);
  
  const handleExportData = () => {
    if (places.length) {
      exportToExcel(places);
    }
  };
  
  const renderContent = () => {
    if (locationError) {
      return (
        <EmptyState
          type="location-error"
          message={locationError}
          onAction={refreshLocation}
          actionLabel="Retry"
        />
      );
    }
    
    if (locationLoading) {
      return (
        <div className="flex flex-col items-center justify-center h-full p-8">
          <Spinner size="lg" className="mb-4" />
          <p className="text-muted-foreground">Getting your location...</p>
        </div>
      );
    }
    
    if (placesLoading) {
      return (
        <div className="flex flex-col items-center justify-center h-full p-8">
          <Spinner size="lg" className="mb-4" />
          <p className="text-muted-foreground">Finding places near you...</p>
        </div>
      );
    }
    
    if (placesError) {
      return (
        <EmptyState
          type="no-results"
          message={placesError}
          onAction={() => fetchPlaces({ location: location!, radius: searchRadius })}
          actionLabel="Retry"
        />
      );
    }
    
    if (places.length === 0) {
      return (
        <EmptyState
          type="no-results"
          message="Try adjusting your filters or increasing the search radius to find more places."
          onAction={() => {
            setSelectedCategories([]);
            setSearchRadius(2000);
          }}
          actionLabel="Reset Filters"
        />
      );
    }
    
    return (
      <div className="flex-1 w-full">
        {showMap ? (
          <div className="h-[calc(100vh-200px)] w-full rounded-lg overflow-hidden">
            <PlaceMap
              userLocation={location}
              places={places}
              onMarkerClick={setSelectedPlace}
              selectedPlace={selectedPlace}
            />
          </div>
        ) : (
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
            {places.map((place, index) => (
              <PlaceCard
                key={place.id}
                place={place}
                index={index}
                onViewDetails={setSelectedPlace}
              />
            ))}
          </div>
        )}
      </div>
    );
  };
  
  return (
    <div className="flex flex-col gap-4">
      <div className="flex items-center justify-between">
        <Button
          variant="ghost"
          onClick={onBack}
          className="flex items-center gap-2"
        >
          <ArrowLeft className="h-4 w-4" />
          Back to Home
        </Button>
        
        {places.length > 0 && (
          <div className="flex items-center gap-2">
            <Button
              variant="outline"
              onClick={handleExportData}
              className="flex items-center gap-2"
            >
              <Download className="h-4 w-4" />
              Export to Excel
            </Button>
            
            <Button
              variant="ghost"
              onClick={() => setShowMap(!showMap)}
            >
              {showMap ? 'Show List' : 'Show Map'}
            </Button>
          </div>
        )}
      </div>

      <div className="flex flex-col lg:flex-row gap-4">
        <div className="w-full lg:w-64 flex-shrink-0">
          <PlaceFilters
            selectedCategories={selectedCategories}
            onCategoryChange={setSelectedCategories}
            searchRadius={searchRadius}
            onRadiusChange={setSearchRadius}
          />
        </div>
        
        <div className="flex-1">
          {renderContent()}
        </div>
      </div>
      
      <AnimatePresence>
        {selectedPlace && (
          <PlaceDetail
            place={selectedPlace}
            onClose={() => setSelectedPlace(null)}
          />
        )}
      </AnimatePresence>
    </div>
  );
}