import { useState, useEffect, useCallback } from 'react';
import { LocationData } from '../types';
import { getCurrentPosition } from '../lib/utils';

interface UseLocationResult {
  location: LocationData | null;
  error: string | null;
  loading: boolean;
  refreshLocation: () => Promise<void>;
}

export function useLocation(): UseLocationResult {
  const [location, setLocation] = useState<LocationData | null>(null);
  const [error, setError] = useState<string | null>(null);
  const [loading, setLoading] = useState<boolean>(true);

  const refreshLocation = useCallback(async () => {
    setLoading(true);
    setError(null);
    
    try {
      const position = await getCurrentPosition();
      
      setLocation({
        latitude: position.coords.latitude,
        longitude: position.coords.longitude,
        accuracy: position.coords.accuracy,
      });
    } catch (err) {
      console.error('Error getting location:', err);
      
      // Handle specific error types
      if (err instanceof GeolocationPositionError) {
        switch (err.code) {
          case err.PERMISSION_DENIED:
            setError('Location access was denied. Please enable location services.');
            break;
          case err.POSITION_UNAVAILABLE:
            setError('Location information is unavailable. Please try again later.');
            break;
          case err.TIMEOUT:
            setError('The request to get location timed out. Please try again.');
            break;
          default:
            setError('An unknown error occurred while getting location.');
        }
      } else {
        setError('Failed to get your location. Please try again.');
      }
    } finally {
      setLoading(false);
    }
  }, []);

  useEffect(() => {
    refreshLocation();
  }, [refreshLocation]);

  return { location, error, loading, refreshLocation };
}