import { useState, useCallback } from 'react';
import { AIQueryParams, Place, PlaceCategory } from '../types';
import { fetchNearbyPlaces } from '../services/mockAiService';

interface UsePlacesResult {
  places: Place[];
  loading: boolean;
  error: string | null;
  fetchPlaces: (params: AIQueryParams) => Promise<void>;
  selectedCategories: PlaceCategory[];
  setSelectedCategories: (categories: PlaceCategory[]) => void;
  searchRadius: number;
  setSearchRadius: (radius: number) => void;
}

export function usePlaces(): UsePlacesResult {
  const [places, setPlaces] = useState<Place[]>([]);
  const [loading, setLoading] = useState<boolean>(false);
  const [error, setError] = useState<string | null>(null);
  const [selectedCategories, setSelectedCategories] = useState<PlaceCategory[]>([]);
  const [searchRadius, setSearchRadius] = useState<number>(1000); // Default 1km

  const fetchPlaces = useCallback(async (params: AIQueryParams) => {
    setLoading(true);
    setError(null);
    
    try {
      // Apply current filter states to the params
      const queryParams: AIQueryParams = {
        ...params,
        radius: searchRadius,
      };
      
      if (selectedCategories.length > 0) {
        queryParams.categories = selectedCategories;
      }
      
      const data = await fetchNearbyPlaces(queryParams);
      setPlaces(data);
    } catch (err) {
      console.error('Error fetching places:', err);
      setError('Failed to fetch nearby places. Please try again.');
    } finally {
      setLoading(false);
    }
  }, [searchRadius, selectedCategories]);

  return {
    places,
    loading,
    error,
    fetchPlaces,
    selectedCategories,
    setSelectedCategories,
    searchRadius,
    setSearchRadius,
  };
}