import { clsx, type ClassValue } from 'clsx';
import { twMerge } from 'tailwind-merge';
// import { utils, writeFile } from 'xlsx';
import type { Place, PlaceCategory } from '../types';

/**
 * Combines multiple class names with Tailwind CSS classes
 */
export function cn(...inputs: ClassValue[]) {
  return twMerge(clsx(inputs));
}

/**
 * Format a distance in meters to a readable format
 */
export function formatDistance(meters: number): string {
  if (meters < 1000) {
    return `${Math.round(meters)}m`;
  }
  
  return `${(meters / 1000).toFixed(1)}km`;
}

/**
 * Format rating to display stars (e.g., "4.5/5")
 */
export function formatRating(rating: number): string {
  return `${rating.toFixed(1)}/5`;
}

/**
 * Format price level to display dollar signs
 */
export function formatPriceLevel(level?: number): string {
  if (!level) return 'N/A';
  
  return '$'.repeat(level);
}

/**
 * Checks if geolocation is supported by the browser
 */
export function isGeolocationSupported(): boolean {
  return 'geolocation' in navigator;
}

/**
 * Get current position as a promise
 */
export function getCurrentPosition(): Promise<GeolocationPosition> {
  return new Promise((resolve, reject) => {
    if (!isGeolocationSupported()) {
      reject(new Error('Geolocation is not supported by your browser'));
      return;
    }
    
    navigator.geolocation.getCurrentPosition(
      (position) => resolve(position),
      (error) => reject(error),
      { enableHighAccuracy: true, timeout: 10000, maximumAge: 0 }
    );
  });
}

/**
 * Export places to an Excel file
 */
// export function exportToExcel(places: Place[], filename = 'nearby-places.xlsx'): void {
//   // Create a new workbook
//   const workbook = utils.book_new();
  
//   // Format the data for Excel
//   const data = places.map((place) => ({
//     Name: place.name,
//     Category: place.category,
//     Address: place.address,
//     Rating: place.rating,
//     Distance: formatDistance(place.distance),
//     'Price Level': formatPriceLevel(place.priceLevel),
//     Website: place.website || 'N/A',
//     Phone: place.phoneNumber || 'N/A',
//     Latitude: place.coordinates.latitude,
//     Longitude: place.coordinates.longitude,
//   }));
  
//   // Convert the data to a worksheet
//   const worksheet = utils.json_to_sheet(data);
  
//   // Add the worksheet to the workbook
//   utils.book_append_sheet(workbook, worksheet, 'Nearby Places');
  
//   // Generate the Excel file
//   writeFile(workbook, filename);
// }

/**
 * Simple debounce function
 */
export function debounce<T extends (...args: any[]) => any>(
  func: T,
  delay: number
): (...args: Parameters<T>) => void {
  let timeoutId: ReturnType<typeof setTimeout>;
  
  return function(...args: Parameters<T>): void {
    clearTimeout(timeoutId);
    timeoutId = setTimeout(() => func(...args), delay);
  };
}

/**
 * Get a category icon name for Lucide icons
 */
export function getCategoryIconName(category: PlaceCategory): string {
  switch (category) {
    case 'restaurant': return 'utensils';
    case 'cafe': return 'coffee';
    case 'bar': return 'glass';
    case 'hotel': return 'bed';
    case 'store': return 'shopping-bag';
    case 'attraction': return 'landmark';
    case 'park': return 'tree';
    case 'gym': return 'dumbbell';
    default: return 'map-pin';
  }
}