import axios from "axios"
import { motion } from "framer-motion";
import { useState } from "react"

interface ApiResponse {
    success: boolean;
    message: string;
    filename?: string;
    file_id?: string;
    places_count?: number;
}

export const Lead = () => {
    const [prompt, setPrompt] = useState("")
    const [aiResponse, setAIResponse] = useState<ApiResponse | null>(null)
    const [loading, setLoading] = useState(false)
    const [downloading, setDownloading] = useState(false)

    const handleClick = async () => {
        if (!prompt.trim()) {
            alert("Please enter a prompt");
            return;
        }

        setLoading(true);
        setAIResponse(null);
        
        try {
            const response = await axios.post<ApiResponse>("http://localhost:3000/v1/generate", {
                user_query: prompt
            });
            
            setAIResponse(response.data);
        } catch (error) {
            console.error("Error:", error);
            setAIResponse({
                success: false,
                message: "Failed to connect to the server. Please try again."
            });
        } finally {
            setLoading(false);
        }
    }

    const handleDownload = async (fileId: string, filename: string) => {
        setDownloading(true);
        
        try {
            const response = await axios.get(`http://localhost:3000/v1/download/${fileId}`, {
                responseType: 'blob',
            });

            // Create blob link to download
            const url = window.URL.createObjectURL(new Blob([response.data]));
            const link = document.createElement('a');
            link.href = url;
            link.setAttribute('download', filename);
            
            // Append to html link element page
            document.body.appendChild(link);
            
            // Start download
            link.click();
            
            // Clean up and remove the link
            link.parentNode?.removeChild(link);
            window.URL.revokeObjectURL(url);
            
        } catch (error) {
            console.error("Download error:", error);
            alert("Failed to download file. Please try again.");
        } finally {
            setDownloading(false);
        }
    }

    return (
        <div className="ml-5 mt-5">
            <motion.div className="flex justify-center text-3xl mb-6 font-bold" initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.2 }}>
                Begin your lead generation now
            </motion.div>
            
            <motion.div className="flex justify-center mb-6" initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.5 }}>
                <input 
                    placeholder="Enter your prompt here..." 
                    className="outline-none rounded mx-2 focus:border px-2 w-1/4 py-2 border border-gray-300" 
                    value={prompt}
                    onChange={(e) => setPrompt(e.target.value)}
                    disabled={loading}
                />
                <button 
                    className={`px-3 py-1 rounded-lg text-lg text-white ${
                        loading 
                            ? 'bg-gray-400 cursor-not-allowed' 
                            : 'bg-blue-500 hover:bg-blue-700'
                    }`} 
                    onClick={handleClick}
                    disabled={loading}
                >
                    {loading ? "Generating..." : "Generate"}
                </button>
            </motion.div>

            {/* Response Display */}
            {aiResponse && (
                <div className="max-w-4xl mx-auto mt-6">
                    <div className={`p-4 rounded-lg ${
                        aiResponse.success ? 'bg-green-100 border-green-500' : 'bg-red-100 border-red-500'
                    } border`}>
                        <h3 className={`text-lg font-semibold mb-2 ${
                            aiResponse.success ? 'text-green-800' : 'text-red-800'
                        }`}>
                            {aiResponse.success ? 'Success!' : 'Error'}
                        </h3>
                        <p className={aiResponse.success ? 'text-green-700' : 'text-red-700'}>
                            {aiResponse.message}
                        </p>
                        
                        {aiResponse.success && aiResponse.filename && (
                            <div className="mt-4">
                                <div className="text-green-700 mb-3">
                                    <p><strong>File:</strong> {aiResponse.filename}</p>
                                    <p><strong>Places found:</strong> {aiResponse.places_count}</p>
                                </div>
                                
                                {aiResponse.file_id && (
                                    <button
                                        onClick={() => handleDownload(aiResponse.file_id!, aiResponse.filename!)}
                                        disabled={downloading}
                                        className={`px-4 py-2 rounded-lg text-white font-medium ${
                                            downloading
                                                ? 'bg-gray-400 cursor-not-allowed'
                                                : 'bg-green-600 hover:bg-green-700'
                                        }`}
                                    >
                                        {downloading ? (
                                            <span className="flex items-center">
                                                <svg className="animate-spin -ml-1 mr-2 h-4 w-4 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                                                    <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
                                                    <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                                                </svg>
                                                Downloading...
                                            </span>
                                        ) : (
                                            <span className="flex items-center">
                                                <svg className="w-4 h-4 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                                                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
                                                </svg>
                                                Download Excel File
                                            </span>
                                        )}
                                    </button>
                                )}
                            </div>
                        )}
                    </div>
                </div>
            )}
        </div>
    )
}